#include <string.h>

#include "config.h"
#include "groupselect.h"
#include "ln_log.h"
#include "pcrewrap.h"

pcre2_code_8 *gs_compile(const char *regex, const char *file, unsigned long line) {
    int regex_errcode;
    size_t regex_errpos;
    pcre2_code_8 *re;
    return ln_pcre_compile(regex, PCRE2_MULTILINE, NULL, file, line);
}

/* match s against PCRE re
 * WARNING: If re is NULL, every string s is considered a match
 * returns 1 for match, 0 for mismatch, negative for error */
int gs_match(const pcre2_code_8 *re, const unsigned char *s) {
    int match;
    pcre2_match_data_8 *match_data;

    if (re == NULL) return 1;
    match_data = pcre2_match_data_create_8(1, NULL);
    if (NULL == match_data) {
        ln_log(LNLOG_SERR, LNLOG_CTOP, "gs_match: out of memory allocating match_data");
        return -1;
    }

    match = pcre2_match_8(re, s, PCRE2_ZERO_TERMINATED, 0,
                          PCRE2_ANCHORED, match_data, NULL);

    pcre2_match_data_free_8(match_data);
    if (match == PCRE2_ERROR_NOMATCH) return 0;
    if (match >= 0) return 1;
    return match; /* match < 0, but not PCRE2_ERROR_NOMATCH */
}
