#include "pcrewrap.h"
#include "ln_log.h"

pcre2_code_8 *ln_pcre_compile(const char *pattern, int options,
	const unsigned char *tableptr, const char *filename,
	unsigned long line)
{
    int regex_errcode;
    size_t regex_errpos;
    pcre2_code_8 *re;

    if (NULL == (re = pcre2_compile_8((const unsigned char *)pattern,
				    PCRE2_ZERO_TERMINATED, PCRE2_MULTILINE, &regex_errcode,
				      &regex_errpos, NULL))) {
	/* could not compile */
	unsigned char regex_errmsg[1024];
	int len = pcre2_get_error_message_8(regex_errcode, regex_errmsg, sizeof(regex_errmsg));
	ln_log(LNLOG_SWARNING, LNLOG_CTOP,
		"%s: invalid pattern at line %lu: %s",
		filename, line, regex_errmsg);
	ln_log(LNLOG_SWARNING, LNLOG_CTOP,
		"%s: \"%s\"", filename, pattern);
	ln_log(LNLOG_SWARNING, LNLOG_CTOP,
		"%s:  %*s",
		filename,
		(int)(regex_errpos + 1), "^");
    }
    return re;
}
